#include <msp430.h> 


/**
 RU: Пример для изучения работы микроконтроллера серии CC430 на отладочной плате TiTAN.
     Это один из сложных примеров, который позволяет познакомиться с трансивером.
     Необходимо иметь две платы. При нажатии на кнопку на одном, происходит передача пакета "0123456789" длиной 10 байт.
     На принимающей плате после принятия пакета моргнет светодиод.
 ENG: An example for studying the operation of a СС430 series microcontroller on a TiTAN debug card.
      This is one of the complex examples that allows you to get acquainted with the transceiver.
      You must have two boards. When you click on the button on one board, the packet is transmitted "0123456789" 
      with a length of 10 bytes. After receiving the packet, the LED on the receiving board will blink.
 author: Valery Beloglazov
 */
#include "main.h"
#include "system.h"
#include "RF1A.h"

#define PACKETSIZE      10                                      // Size of data in packet
#define RSSISIZE        1                                       // Size of RSSI data in packet
#define LQISIZE         1                                       // Size of LQI data in packet

unsigned char RxBuff[PACKETSIZE + RSSISIZE + LQISIZE];          // Buffer for RX data with RSSI and LQI
unsigned char TxBuff[PACKETSIZE];                               // Buffer for TX data without RRSI and LQI
unsigned char RxSize;                                           // received bytes in payload
unsigned char RxRSSI;                                           // RSSI value in payload
unsigned char RxLQI;                                            // LQI value in payload



int main(void)
{
	WDTCTL = WDTPW | WDTHOLD;	                        // stop watchdog timer
    SetSystemClock20MHz();                              // set system clock

    LEDDIR |= LED;                                     // set pin to output

    KEYDIR &= ~KEY;                                     // set pin to input mode
    KEYOUT |= KEY;                                      // select pull-up resistor
    KEYREN |= KEY;                                      // enable pull-up (or pull-down) resistor

    __enable_interrupt();                               // global interrupt enabled

	while(1) {
	    while(GETKEY);                                  // wait for push button
	    LEDON;
	    TxBuff[0]='0';                                  // save data to TxBuff
	    TxBuff[1]='1';
	    TxBuff[2]='2';
	    TxBuff[3]='3';
	    TxBuff[4]='4';
	    TxBuff[5]='5';
	    TxBuff[6]='6';
	    TxBuff[7]='7';
	    TxBuff[8]='8';
	    TxBuff[9]='9';
	    WriteBurstReg(RF_TXFIFOWR, TxBuff, PACKETSIZE);             // Put TxBuff in transmit payload
	    TransmitOn();                                               // start transmission
        ResetRadioCore();								            // reset radiocore
        InitRadio();								                // init radiocore
        Strobe( RF_SIDLE );								            // idle mode
        Strobe( RF_SCAL );								            // calibration freq
        Strobe( RF_SRX );								            // switch to RX mode
        LEDOFF;
        delay_ms(100);
	}
	return 0;
}




#pragma vector=CC1101_VECTOR
__interrupt void CC1101_ISR(void)
{
  switch(__even_in_range(RF1AIV,32))        // Prioritizing Radio Core Interrupt
  {
    case  0: break;                         // No RF core interrupt pending
    case  2: break;                         // RFIFG0
    case  4: break;                         // RFIFG1
    case  6: break;                         // RFIFG2
    case  8: break;                         // RFIFG3
    case 10: break;                         // RFIFG4
    case 12: break;                         // RFIFG5
    case 14: break;                         // RFIFG6
    case 16: break;                         // RFIFG7
    case 18: break;                         // RFIFG8
    case 20: {                              // RFIFG9
        if((RF1AIES & BIT9)) {                // RX sync word received
            LEDON;
            RxSize = ReadSingleReg(RXBYTES);                            // read Rx payload size
            if (RxSize == (PACKETSIZE + RSSISIZE + LQISIZE)) {
                ReadBurstReg(RF_RXFIFORD, RxBuff, RxSize);	            // read Rx payload
                RxRSSI = RxBuff[RxSize-2];                              // my RSSI
                RxLQI = RxBuff[RxSize-1];                               // my LQI
                //OK! All data received
            }
            // reset radiocore and go to RX mode
            ResetRadioCore();								            // reset radiocore
            InitRadio();								                // init radiocore
            Strobe( RF_SIDLE );								            // idle mode
            Strobe( RF_SCAL );								            // calibration freq
            Strobe( RF_SRX );								            // switch to RX mode
            LEDOFF;
        }
        break;
    }
    case 22: break;                         // RFIFG10
    case 24: break;                         // RFIFG11
    case 26: break;                         // RFIFG12
    case 28: break;                         // RFIFG13
    case 30: break;                         // RFIFG14
    case 32: break;                         // RFIFG15
  }
}

